@@ -43,23 +43,40 @@
 #'     DD = qcv(terms="")
 #' )
 #' 
-#' 
+#' ## Single occurrence version
 #' (x <- cm_range2long(foo))
+#' 
+#' cm_code.blank(x, combine.code.list = list(ABC=qcv(AA, BB, CC)),
+#'     overlap = "!=1")
+#' 
+#' ## Repeated measures version
 #' (z <- cm_range2long(foo, foo2, v.name="time"))
-#' cm_code.transform(x, overlap.code.list=list(AB=qcv(AA, BB)))
-#' cm_code.transform(x, combine.code.list = list(ALL=qcv(AA, BB, CC)))
-#' cm_code.transform(x, overlap.code.list=list(AB=qcv(AA, BB)), 
-#'     combine.code.list = list(ALL=qcv(AA, BB, CC)))
-#' overlaps <- list(AB=qcv(AA, BB), ABC=qcv(AA, BB, CC))
-#' cm_code.transform(z, overlaps, rm.var="time")
-#' out1 <- cm_code.transform(z, overlaps, 
-#'    exclude.code.list=list(AABB_no_CC = qcv(AA, BB, CC)), rm.var="time")
-#' head(out1, 10)
+#' 
+#' cm_code.blank(z, combine.code.list = list(ABC=qcv(AA, BB, CC)),
+#'     rm.var = "time", overlap = "!=1")
+#' 
+#' cm_code.blank(z, combine.code.list = list(AB=qcv(AA, BB)),
+#'     rm.var = "time", overlap = TRUE)
+#' 
+#' cm_code.blank(z, combine.code.list = list(AB=qcv(AA, BB)),
+#'     rm.var = "time", overlap = FALSE)
+#' 
+#' cm_code.blank(z, combine.code.list = list(AB=qcv(AA, BB)),
+#'     rm.var = "time", overlap = ">1")
+#' 
+#' cm_code.blank(z, combine.code.list = list(AB=qcv(AA, BB)),
+#'     rm.var = "time", overlap = "==2")
+#' 
+#' ## Notice `overlap = "==2"` above is identical to `cm_code.overlap`
+#' cm_code.overlap(z, overlap.code.list = list(AB=qcv(AA, BB)),
+#'     rm.var = "time")
+#' 
+#' 
 #' #WITH cm_time2long
 #' x <- list(
 #'     transcript_time_span = qcv(00:00 - 1:12:00),
 #'     A = qcv(terms = "2.40:3.00, 5.01, 6.02:7.00, 9.00"),
-#'     B = qcv(terms = "2.40, 3.01:3.02, 5.01, 6.02:7.00, 9.00, 
+#'     B = qcv(terms = "2.40, 3.01:3.02, 5.01, 6.02:7.00, 9.00,
 #'         1.12.00:1.19.01"),
 #'     C = qcv(terms = "2.40:3.00, 5.01, 6.02:7.00, 9.00, 17.01")
 #' )
@@ -67,17 +84,18 @@
 #' y <- list(
 #'     transcript_time_span = qcv(00:00 - 1:12:00),
 #'     A = qcv(terms = "2.40:3.00, 5.01, 6.02:7.00, 9.00"),
-#'     B = qcv(terms = "2.40, 3.01:3.02, 5.01, 6.02:7.00, 9.00, 
+#'     B = qcv(terms = "2.40, 3.01:3.02, 5.01, 6.02:7.00, 9.00,
 #'         1.12.00:1.19.01"),
 #'     C = qcv(terms = "2.40:3.00, 5.01, 6.02:7.00, 9.00, 17.01")
 #' )
 #' 
-#' dat <- cm_time2long(x, y)
+#' dat <- cm_time2long(x, y, v.name="time")
 #' head(dat, 10)
-#' out2 <- cm_code.transform(dat, list(P=qcv(A, B), Q=qcv(B, C), R=qcv(A, B, C)), 
-#'     list(S=qcv(A, B), T=qcv(B, C), U=qcv(A, B, C)), 
-#'     list(ABnoC = qcv(A, B, C)), rm.var="variable")
-#' head(out2, 10)
+#' out <- cm_code.blank(dat, combine.code.list = list(ABC=qcv(A, B, C)),
+#'     rm.var = "time", overlap = "!=1")
+#' 
+#' head(out)
+#' plot(out)
 #' }
 cm_code.blank <- function(x2long.obj, combine.code.list, rm.var = NULL, overlap = TRUE) {
     NMS <- as.character(substitute(x2long.obj))
@@ -90,6 +108,20 @@ cm_code.blank <- function(x2long.obj, combine.code.list, rm.var = NULL, overlap
     if (is.null(rm.var)) {
         colnames(x1) <- gsub("long.obj.", "", colnames(x1))
     }
+    
+    ## added 11-6-13 to deal with codes in rep mes. not found in both
+    cols <- unique(unlist(lapply(x1, colnames)))
+    if (!is.matrix(x1)) {
+        x1 <- lapply(x1, function(x, y =cols) {
+            addon <- y[!y %in% colnames(x)]
+            if (is.null(addon) | identical(addon, character(0))) return(x)
+            mat <- matrix(rep(0, nrow(x)*length(addon)), ncol = length(addon))
+            colnames(mat) <- addon
+            dat <- data.frame(x, mat)
+            dat[, sort(colnames(dat))]
+        })
+    }
+    
     x2 <- cm_combine.dummy(x1, combine.code = combine.code.list, 
         rm.var = rm.var, overlap = overlap)
     if (is.null(rm.var)) {
@@ -101,15 +133,18 @@ cm_code.blank <- function(x2long.obj, combine.code.list, rm.var = NULL, overlap
         rm.var <- "time"
     }
     DF <- cm_dummy2long(x2, rm.var = rm.var)
-    if (comment(x2long.obj) == "cmtime") {
+    if (which.cm(x2long.obj) == "cmtime") {
         DF$start <- DF$start + 1
         DF$Start <- sec2hms(DF$start)
         DF$End <- sec2hms(DF$end) 
         DF <- data.frame(DF[, -4, drop=FALSE], DF[, 4, drop=FALSE])
+        class(DF) <- class(DF)[!grepl("vname_", class(DF))]
+        class(DF) <- c("cmspans", which.cm(x2long.obj), 
+            paste0("vname_", rm.var), class(DF))
     }
-    comment(DF) <- comment(x2long.obj)
     if (rmv) {
         DF$time <- NULL
+        class(DF) <- class(DF)[!grepl("vname_", class(DF))]
     }
     DF
 }
